/// <reference types="emscripten" />
import { BrowserTypes } from "@dannadori/worker-base";
import { Face, Keypoint } from "@tensorflow-models/face-landmarks-detection";
import { BoundingBox } from "@tensorflow-models/face-landmarks-detection/dist/shared/calculators/interfaces/shape_interfaces";
import { Hand } from "@tensorflow-models/hand-pose-detection";
import { Pose } from "@tensorflow-models/pose-detection";
export declare const WorkerCommand: {
    readonly INITIALIZE: "initialize";
    readonly PREDICT: "predict";
};
export declare type WorkerCommand = typeof WorkerCommand[keyof typeof WorkerCommand];
export declare const WorkerResponse: {
    readonly INITIALIZED: "initialized";
    readonly PREDICTED: "predicted";
};
export declare type WorkerResponse = typeof WorkerResponse[keyof typeof WorkerResponse];
export declare const OperationType: {
    readonly hand: "hand";
    readonly face: "face";
    readonly pose: "pose";
};
export declare type OperationType = typeof OperationType[keyof typeof OperationType];
export interface ModelConfig {
    detectionConfidence: number;
    maxPoses: number;
}
export interface MediapipeMixConfig {
    browserType: BrowserTypes;
    processOnLocal: boolean;
    pageUrl: string;
    palmDetectorModelTFLites: {
        [key: string]: string;
    };
    handLandmarkModelTFLites: {
        [key: string]: string;
    };
    handModelKey: string;
    faceDetectorModelTFLites: {
        [key: string]: string;
    };
    faceLandmarkModelTFLites: {
        [key: string]: string;
    };
    faceModelKey: string;
    poseDetectorModelTFLites: {
        [key: string]: string;
    };
    poseLandmarkModelTFLites: {
        [key: string]: string;
    };
    poseModelKey: string;
    wasmSimdBase64: string;
    maxProcessWidth: number;
    maxProcessHeight: number;
}
export interface MediapipeMixOperationParams {
    operationType: OperationType;
    handProcessWidth: number;
    handProcessHeight: number;
    handMaxHands: number;
    handAffineResizedFactor: number;
    faceProcessWidth: number;
    faceProcessHeight: number;
    faceMaxFaces: number;
    faceMovingAverageWindow: number;
    poseProcessWidth: number;
    poseProcessHeight: number;
    poseMaxPoses: number;
    poseMovingAverageWindow: number;
    poseAffineResizedFactor: number;
    poseCropExt: number;
    poseCalculateMode: number;
}
export declare type HandPredictionEx = {
    operationType: OperationType;
    rowPrediction: Hand[] | null;
};
export declare type FacePredictionEx = {
    operationType: OperationType;
    rowPrediction: Face[] | null;
    singlePersonKeypointsMovingAverage?: Keypoint[];
    singlePersonBoxMovingAverage?: BoundingBox;
};
export declare type PosePredictionEx = {
    operationType: OperationType;
    rowPrediction: Pose[] | null;
    singlePersonKeypointsMovingAverage?: Keypoint[];
    singlePersonKeypoints3DMovingAverage?: Keypoint[];
    singlePersonBoxMovingAverage?: BoundingBox;
};
export interface TFLite extends EmscriptenModule {
    /** Hand  **/
    _getHandInputBufferAddress(): number;
    _getHandOutputBufferAddress(): number;
    _getHandTemporaryBufferAddress(): number;
    _getPalmDetectorModelBufferAddress(): number;
    _getHandLandmarkModelBufferAddress(): number;
    _initPalmDetectorModelBuffer(size: number): void;
    _initHandLandmarkModelBuffer(size: number): void;
    _initHandInputBuffer(width: number, height: number, channel: number): void;
    _loadPalmDetectorModel(bufferSize: number): number;
    _loadHandLandmarkModel(bufferSize: number): number;
    _execHand(widht: number, height: number, max_palm_num: number, resizedFactor: number): number;
    /** Face */
    _getFaceInputBufferAddress(): number;
    _getFaceOutputBufferAddress(): number;
    _getFaceTemporaryBufferAddress(): number;
    _getFaceDetectorModelBufferAddress(): number;
    _getFaceLandmarkModelBufferAddress(): number;
    _initFaceDetectorModelBuffer(size: number): void;
    _initFaceLandmarkModelBuffer(size: number): void;
    _initFaceInputBuffer(width: number, height: number, channel: number): void;
    _loadFaceDetectorModel(bufferSize: number): number;
    _loadFaceLandmarkModel(bufferSize: number): number;
    _execFace(widht: number, height: number, max_face_num: number): number;
    /** Pose  **/
    _getPoseInputBufferAddress(): number;
    _getPoseOutputBufferAddress(): number;
    _getPoseTemporaryBufferAddress(): number;
    _getPoseDetectorModelBufferAddress(): number;
    _getPoseLandmarkModelBufferAddress(): number;
    _initPoseDetectorModelBuffer(size: number): void;
    _initPoseLandmarkModelBuffer(size: number): void;
    _initPoseInputBuffer(width: number, height: number, channel: number): void;
    _loadPoseDetectorModel(bufferSize: number): number;
    _loadPoseLandmarkModel(bufferSize: number): number;
    _execPose(widht: number, height: number, max_pose_num: number, resizedFactor: number, cropExt: number): number;
    _set_pose_calculate_mode(mode: number): number;
}
export declare type TFLiteHand = {
    score: number;
    landmarkScore: number;
    handedness: number;
    rotation: number;
    palm: {
        minX: number;
        minY: number;
        maxX: number;
        maxY: number;
    };
    hand: {
        minX: number;
        minY: number;
        maxX: number;
        maxY: number;
    };
    rotatedHand: {
        positions: {
            x: number;
            y: number;
        }[];
    };
    palmKeypoints: {
        x: number;
        y: number;
    }[];
    landmarkKeypoints: {
        x: number;
        y: number;
        z: number;
    }[];
};
export declare type TFLiteFaceLandmarkDetection = {
    score: number;
    landmarkScore: number;
    rotation: number;
    face: {
        minX: number;
        minY: number;
        maxX: number;
        maxY: number;
    };
    faceWithMargin: {
        minX: number;
        minY: number;
        maxX: number;
        maxY: number;
    };
    rotatedFace: {
        positions: {
            x: number;
            y: number;
        }[];
    };
    faceKeypoints: {
        x: number;
        y: number;
    }[];
    landmarkKeypoints: {
        x: number;
        y: number;
        z: number;
    }[];
    landmarkLipsKeypoints: {
        x: number;
        y: number;
    }[];
    landmarkLeftEyeKeypoints: {
        x: number;
        y: number;
    }[];
    landmarkRightEyeKeypoints: {
        x: number;
        y: number;
    }[];
    landmarkLeftIrisKeypoints: {
        x: number;
        y: number;
    }[];
    landmarkRightIrisKeypoints: {
        x: number;
        y: number;
    }[];
};
export declare type TFLitePoseLandmarkDetection = {
    score: number;
    landmarkScore: number;
    rotation: number;
    pose: {
        minX: number;
        minY: number;
        maxX: number;
        maxY: number;
    };
    poseWithMargin: {
        minX: number;
        minY: number;
        maxX: number;
        maxY: number;
    };
    rotatedPose: {
        positions: {
            x: number;
            y: number;
        }[];
    };
    poseKeypoints: {
        x: number;
        y: number;
    }[];
    landmarkKeypoints: {
        x: number;
        y: number;
        z: number;
        score: number;
        visibility: number;
        presence: number;
    }[];
    landmarkKeypoints3D: {
        x: number;
        y: number;
        z: number;
        score: number;
        visibility?: number;
        presence?: number;
    }[];
};
export declare const PartsLookupIndices: {
    [key: string]: number[];
};
export declare const FingerLookupIndices: {
    [key: string]: number[];
};
