import { LocalWorker, WorkerManagerBase } from "@dannadori/worker-base";
import { NUM_KEYPOINTS, TRIANGULATION } from "./facePoints";
import { FacePredictionEx, FingerLookupIndices, HandPredictionEx, MediapipeMixConfig, MediapipeMixOperationParams, OperationType, PartsLookupIndices, PosePredictionEx, TFLite } from "./const";
import { Pose } from "@tensorflow-models/pose-detection";
import { Hand } from "@tensorflow-models/hand-pose-detection/dist/types";
import { Face } from "@tensorflow-models/face-landmarks-detection/dist/types";
export { OperationType, MediapipeMixConfig, MediapipeMixOperationParams, HandPredictionEx, FacePredictionEx, PosePredictionEx, PartsLookupIndices, TRIANGULATION, NUM_KEYPOINTS, FingerLookupIndices };
export declare const generateMediapipeMixDefaultConfig: () => MediapipeMixConfig;
export declare const generateDefaultMediapipeMixParams: () => MediapipeMixOperationParams;
export declare class LocalMM extends LocalWorker {
    tflite: TFLite | null;
    tfliteHandInputAddress: number;
    tfliteHandOutputAddress: number;
    tfliteFaceInputAddress: number;
    tfliteFaceOutputAddress: number;
    tflitePoseInputAddress: number;
    tflitePoseOutputAddress: number;
    init: (config: MediapipeMixConfig) => Promise<void>;
    predict: (config: MediapipeMixConfig, params: MediapipeMixOperationParams, targetCanvas: HTMLCanvasElement) => Promise<Hand[] | Face[] | Pose[] | null>;
    predictHand: (config: MediapipeMixConfig, params: MediapipeMixOperationParams, targetCanvas: HTMLCanvasElement) => Promise<Hand[]>;
    predictFace: (config: MediapipeMixConfig, params: MediapipeMixOperationParams, targetCanvas: HTMLCanvasElement) => Promise<Face[]>;
    predictPose: (_config: MediapipeMixConfig, params: MediapipeMixOperationParams, targetCanvas: HTMLCanvasElement) => Promise<Pose[]>;
}
export declare class MediapipeMixWorkerManager extends WorkerManagerBase {
    private config;
    localWorker: LocalMM;
    init: (config: MediapipeMixConfig | null) => Promise<void>;
    predict: (params: MediapipeMixOperationParams, targetCanvas: HTMLCanvasElement | HTMLVideoElement) => Promise<HandPredictionEx | FacePredictionEx | PosePredictionEx>;
    generateHandPredictionEx: (config: MediapipeMixConfig, params: MediapipeMixOperationParams, prediction: Hand[] | null) => HandPredictionEx;
    facesMV: Face[][];
    generateFacePredictionEx: (config: MediapipeMixConfig, params: MediapipeMixOperationParams, prediction: Face[] | null) => FacePredictionEx;
    posesMV: Pose[][];
    generatePosePredictionEx: (config: MediapipeMixConfig, params: MediapipeMixOperationParams, prediction: Pose[] | null) => PosePredictionEx;
    fitCroppedArea: (prediction: FacePredictionEx, orgWidth: number, orgHeight: number, processedWidth: number, processedHeight: number, outputWidth: number, outputHeight: number, extendRatioTop: number, extendRatioBottom: number, extendRatioLeft: number, extendRatioRight: number) => {
        xmin: number;
        ymin: number;
        width: number;
        height: number;
    };
}
